@@ -3,7 +3,7 @@
 // Copyright (C) 2005 - 2007 Dominick Samperi
 // Copyright (C) 2007 - 2009 Dirk Eddelbuettel <edd@debian.org>
 //
-// $Id: bermudan.cpp 119 2009-11-02 22:47:22Z edd $
+// $Id: bermudan.cpp 138 2010-01-13 21:42:07Z edd $
 //
 // This program is part of the RQuantLib library for R (GNU S).
 // It is made available under the terms of the GNU General Public
@@ -340,7 +340,7 @@ RcppExport SEXP QL_BermudanSwaption(SEXP params, SEXP tsQuotes,
     }
 
     if(exceptionMesg != NULL)
-	error(exceptionMesg);
+	Rf_error(exceptionMesg);
 
     return rl;
 }
