@@ -5,7 +5,7 @@
 // Copyright 2002 - 2009  Dirk Eddelbuettel <edd@debian.org>
 // Copyright 2005 - 2006  Dominick Samperi
 //
-// $Id: rquantlib.hpp 90 2009-06-26 04:54:23Z knguyen $
+// $Id: rquantlib.hpp 138 2010-01-13 21:42:07Z edd $
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -31,12 +31,12 @@
 using namespace QuantLib;
 
 
-#include <R.h>
-#include <Rinternals.h>
+//#include <R.h>
+//#include <Rinternals.h>
 
 #include "Rcpp.h"
 
-#define NULL_RateHelper (boost::shared_ptr<RateHelper>)Null<boost::shared_ptr<RateHelper> >()
+//#define NULL_RateHelper (boost::shared_ptr<RateHelper>)Null<boost::shared_ptr<RateHelper> >()
 
 // Prototypes for convenience functions (some macros)
 void insertListElement(SEXP &list, SEXP &names,
@@ -143,6 +143,7 @@ int dateFromR(const RcppDate &d);
 
 //utility functions for parameters of fixed-income instrument function
 Frequency getFrequency(const double n);
+TimeUnit getTimeUnit(const double n);
 Compounding getCompounding(const double n);
 BusinessDayConvention getBusinessDayConvention(const double n);
 DayCounter getDayCounter(const double n);
@@ -157,4 +158,5 @@ boost::shared_ptr<YieldTermStructure> getFlatCurve(SEXP flatcurve);
 boost::shared_ptr<YieldTermStructure> rebuildCurveFromZeroRates(
                                                                 SEXP dateSexp,
                                                                 SEXP zeroSexp);
+Calendar* getCalendar(SEXP calParameters);
 #endif
