@@ -4,7 +4,7 @@
 //
 // Copyright (C) 2002 - 2009 Dirk Eddelbuettel <edd@debian.org>
 //
-// $Id: vanilla.cpp 55 2009-03-31 01:36:03Z edd $
+// $Id: vanilla.cpp 138 2010-01-13 21:42:07Z edd $
 //
 // This file is part of the RQuantLib library for GNU R.
 // It is made available under the terms of the GNU General Public
@@ -89,7 +89,7 @@ RcppExport  SEXP QL_EuropeanOption(SEXP optionParameters) {
     }
   
     if(exceptionMesg != NULL)
-        error(exceptionMesg);
+        Rf_error(exceptionMesg);
     
     return rl;
 }
@@ -169,7 +169,7 @@ RcppExport  SEXP QL_AmericanOption(SEXP optionParameters) {
     }
   
     if(exceptionMesg != NULL)
-        error(exceptionMesg);
+        Rf_error(exceptionMesg);
     
   return rl;
 }
